package com.ruoyi.bst.model.service.impl;

import java.util.ArrayList;
import java.util.List;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.support.TransactionTemplate;

import com.ruoyi.bst.model.domain.ModelQuery;
import com.ruoyi.bst.model.domain.ModelVO;
import com.ruoyi.bst.model.domain.dto.ModelDTO;
import com.ruoyi.bst.model.mapper.ModelMapper;
import com.ruoyi.bst.model.service.ModelService;
import com.ruoyi.bst.modelSuit.domain.ModelSuit;
import com.ruoyi.bst.modelSuit.service.ModelSuitService;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.common.utils.ServiceUtil;

/**
 * 车辆型号Service业务层处理
 *
 * @author ruoyi
 * @date 2025-03-18
 */
@Service
public class ModelServiceImpl implements ModelService
{

    @Autowired
    private ModelMapper modelMapper;

    @Autowired
    private TransactionTemplate transactionTemplate;

    @Autowired
    private ModelSuitService modelSuitService;

    /**
     * 查询车辆型号
     *
     * @param id 车辆型号主键
     * @return 车辆型号
     */
    @Override
    public ModelVO selectModelById(Long id)
    {
        return modelMapper.selectModelById(id);
    }

    /**
     * 查询车辆型号列表
     *
     * @param model 车辆型号
     * @return 车辆型号
     */
    @Override
    public List<ModelVO> selectModelList(ModelQuery model)
    {
        return modelMapper.selectModelList(model);
    }

    /**
     * 新增车辆型号
     *
     * @param model 车辆型号
     * @return 结果
     */
    @Override
    public int insertModel(ModelDTO dto)
    {
        dto.setCreateTime(DateUtils.getNowDate());

        Integer result = transactionTemplate.execute(status -> {
            int rows = modelMapper.insertModel(dto);

            if (rows > 0) {
                this.updateModelSuit(dto);
            }

            return rows;
        });

        return result == null ? 0 : result;
    }

    /**
     * 修改车辆型号
     *
     * @param model 车辆型号
     * @return 结果
     */
    @Override
    public int updateModel(ModelDTO dto)
    {
        Integer result = transactionTemplate.execute(status -> {
            int rows = modelMapper.updateModel(dto);

            if (rows > 0) {
                this.updateModelSuit(dto);
            }

            return rows;
        });

        return result == null ? 0 : result;
    }
    
    private void updateModelSuit(ModelDTO dto) {
        if (dto.getSuitIds() == null) {
            return;
        }

        // 删除旧的关系
        modelSuitService.deleteByModelId(dto.getId());

        // 新增新的关系
        List<ModelSuit> modelSuitList = new ArrayList<>();
        for (Long suitId : dto.getSuitIds()) {
            if (suitId == null) {
                continue;
            }
            ModelSuit modelSuit = new ModelSuit();
            modelSuit.setModelId(dto.getId());
            modelSuit.setSuitId(suitId);
            modelSuitList.add(modelSuit);
        }
        int rows = modelSuitService.batchInsert(modelSuitList);
        ServiceUtil.assertion(rows != modelSuitList.size(), "新增车型与收费模版关系失败");
    }

    /**
     * 批量删除车辆型号
     *
     * @param ids 需要删除的车辆型号主键
     * @return 结果
     */
    @Override
    public int deleteModelByIds(Long[] ids)
    {
        return modelMapper.deleteModelByIds(ids);
    }

    /**
     * 删除车辆型号信息
     *
     * @param id 车辆型号主键
     * @return 结果
     */
    @Override
    public int deleteModelById(Long id)
    {
        return modelMapper.deleteModelById(id);
    }
}
